#ifndef EZC3D_ALL_H
#define EZC3D_ALL_H
///
/// \file ezc3d_all.h
/// \brief Include all the necessary files to enjoy ezc3ding
/// \author Pariterre
/// \version 1.0
/// \date March 27th, 2020
///

#include "ezc3d/ezc3dNamespace.h"
#include "ezc3d/math/ezc3dMath.h"
#include "ezc3d/ezc3d.h"
#include "ezc3d/Header.h"
#include "ezc3d/Parameters.h"
#include "ezc3d/Data.h"

#include "ezc3d/PointsInfo.h"
#include "ezc3d/AnalogsInfo.h"
#include "ezc3d/RotationsInfo.h"

#include "ezc3d/modules/ForcePlatforms.h"

#endif
